#ifndef DISPLAY_H
#define DISPLAY_H

#include <Arduino.h>
//#include <SSD1306.h>
#include "SSD1306Wire.h" 
#define DISPLAY_ADDRESS         0x3c  // CS  --> NSS
#define DISPLAY_SDA             4
#define DISPLAY_SCL             15  // IRQ --> DIO0


class Display {
public:
    Display();

    void setup_display();
    void display_toggle(bool toggle);
    void cleanTFT();
                
    void show_display(String header, int wait = 0);
    void show_display(String header, String line1, int wait = 0);
    void show_display(String header, String line1, String line2, int wait = 0);
    void show_display(String header, String line1, String line2, String line3, int wait = 0);    
    void show_display(String header, String line1, String line2, String line3, String line4, int wait = 0);
    void show_message(const char* message, int line = 0, int wait = 0);

private:
    SSD1306Wire display;
    bool displayOn;
};

#endif /* DISPLAY_H */
